@@ -1,10 +1,9 @@
 mdes.bira3r1 <- function(power=.80, alpha=.05, two.tailed=TRUE,
                         rho2, rho3, omega2, omega3,
                         p=.50, r21=0, r2t2=0, r2t3=0, g3=0,
-                        n, J, K, ...){
+                        n, J, K){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   df <- K - g3 - 1
@@ -34,10 +33,9 @@ mdes.bira3r1 <- function(power=.80, alpha=.05, two.tailed=TRUE,
 power.bira3r1 <- function(es=.25, alpha=.05, two.tailed=TRUE,
                          rho2, rho3, omega2, omega3,
                          p=.50, r21=0, r2t2=0, r2t3=0, g3=0,
-                         n, J, K, ...){
+                         n, J, K){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   df <- K - g3 - 1
@@ -65,10 +63,9 @@ power.bira3r1 <- function(es=.25, alpha=.05, two.tailed=TRUE,
 mrss.bira3r1 <- function(es=.25, power=.80, alpha=.05, two.tailed=TRUE,
                          n, J, K0=10, tol=.10,
                          rho2, rho3, omega2, omega3,
-                         p=.50, r21=0, r2t2=0, r2t3=0, g3=0, ...){
+                         p=.50, r21=0, r2t2=0, r2t3=0, g3=0){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   i <- 0
